@@ -1,25 +1,17 @@
 #!/bin/bash
 
 # Fail on any error
-set -eo pipefail
+set -eo
 
 # Display commands being run
 set -x
 
-# Only run the linter on go1.11, since it needs type aliases (and we only care about its output once).
-# TODO(deklerk) We should pass an environment variable from kokoro to decide this logic instead.
-if [[ `go version` != *"go1.12"* ]]; then
-    exit 0
+if [[ $KOKORO_JOB_NAME != *"latest-version"* ]]; then
+  exit 0
 fi
 
-export GO111MODULE=on
-
-go install \
-  github.com/golang/protobuf/proto \
-  github.com/golang/protobuf/protoc-gen-go \
-  golang.org/x/lint/golint \
-  golang.org/x/tools/cmd/goimports \
-  honnef.co/go/tools/cmd/staticcheck
+# Look at all .go files (ignoring .pb.go files) and make sure they have a Copyright. Fail if any don't.
+find . -type f -name "*.go" ! -name "*.pb.go" -exec grep -L "\(Copyright [0-9]\{4,\}\)" {} \; 2>&1 | tee /dev/stderr | (! read)
 
 # Fail if a dependency was added without the necessary go.mod/go.sum change
 # being part of the commit.
@@ -27,11 +19,15 @@ go mod tidy
 git diff go.mod | tee /dev/stderr | (! read)
 git diff go.sum | tee /dev/stderr | (! read)
 
+pushd v2
+  go mod tidy
+  git diff go.mod | tee /dev/stderr | (! read)
+  git diff go.sum | tee /dev/stderr | (! read)
+popd
+
 # Easier to debug CI.
 pwd
 
-# Look at all .go files (ignoring .pb.go files) and make sure they have a Copyright. Fail if any don't.
-git ls-files "*[^.pb].go" | xargs grep -L "\(Copyright [0-9]\{4,\}\)" 2>&1 | tee /dev/stderr | (! read)
 gofmt -s -d -l . 2>&1 | tee /dev/stderr | (! read)
 goimports -l . 2>&1 | tee /dev/stderr | (! read)
 
